"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const crypto_1 = __importDefault(require("crypto"));
const qs_1 = __importDefault(require("qs"));
const common_1 = require("../common");
const types_1 = require("../../../types");
const generateSignature = (data, path, secret, nonce) => {
    const secretBuffer = new Buffer(secret, 'base64');
    const hash = crypto_1.default.createHash('sha256');
    const hmac = crypto_1.default.createHmac('sha512', secretBuffer);
    const hashDigest = hash.update(nonce + data).digest('binary');
    const hmacDigest = hmac
        .update(path + hashDigest, 'binary')
        .digest('base64');
    return hmacDigest;
};
exports.add = (trade, options) => __awaiter(this, void 0, void 0, function* () {
    const path = '/0/private/AddOrder';
    const url = `${common_1.getHttpPrefix(trade.network)}${path}`;
    const base = trade.pair.base;
    const quote = trade.pair.quote;
    const nonce = !!options.nonce ? options.nonce : Date.now() * 1000;
    const data = qs_1.default.stringify(Object.assign({ nonce, pair: `${base.symbol}${quote.symbol}`, type: trade.side.toLowerCase(), ordertype: trade.type.toLowerCase(), volume: trade.volume }, (trade.type === types_1.OrderType.LIMIT && {
        price: trade.price,
    })));
    const key = options.auth.key;
    const secret = options.auth.secret;
    const signature = generateSignature(data, path, secret, nonce);
    return axios_1.default.post(url, data, {
        headers: {
            'API-Key': key,
            'API-Sign': signature,
        },
    });
});
